import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertThrows;

class BankAccountNestedTest {
    @Test
    @DisplayName("Withdraw 500 successfully")
    void testWithdraw() {
        BankAccount bankAccount = BankAccount.builder()
                .balance(500.00)
                .minimumBalance(-1000.00).build();
        bankAccount.withDraw(300.00);
        assertEquals(200, bankAccount.getBalance());
    }

    @Test
    @DisplayName("Deposit 400 successfully")
    void testDeposit() {
        BankAccount bankAccount = BankAccount.builder()
                .balance(400.00)
                .minimumBalance(0.00).build();
        bankAccount.deposit(500);
        assertEquals(900.00, bankAccount.getBalance());
    }

    @Nested
    class WhenBalanceEqualsZero {
        @Test
        @DisplayName("test withdraw minimum balance is 0")
        void testWithdrawMinimumBalanceIs0() {
            BankAccount bankAccount = BankAccount.builder()
                    .balance(0.00)
                    .minimumBalance(0.00).build();
            assertThrows(RuntimeException.class, () -> bankAccount.withDraw(500.00));
        }

        @Test
        @DisplayName("test withdraw minimum balance negative 1000")
        void testWithdrawMinimumBalanceNegative1000() {
            BankAccount bankAccount = BankAccount.builder()
                    .balance(0.00)
                    .minimumBalance(-1000.00).build();
            bankAccount.withDraw(500.00);
            assertEquals(-500.00, bankAccount.getBalance());
        }
    }
}